==> WB-11P_1.1.1.239.tar.gz: upgrade.sh <==
#!/bin/sh

echo "Start firmware upgrading" > /dev/console

# some validation
if [ -f "./fmw_board_type" ]; then
    cur_board=`factory board | sed y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/ | sed s/-//g | grep -o ^[A-Z]*[0-9]*`
    case "$cur_board"  in
    "WB10")    board_type="WB1x";;
    "WB11")    board_type="WB1x";;
    esac

    if [ -z "$board_type" ]; then
        echo "UPGRADE FAIL: wrong factory settings" > /dev/console
        exit 1;
    fi

    fmw_type=`cat ./fmw_board_type`
    if [ "$fmw_type" != "$board_type" ]; then
        echo "UPGRADE FAIL: firmware for $fmw_type but board is $cur_board" > /dev/console
        exit 1;
    fi
fi

md5_cur=`busybox md5sum ./linux.bin | cut -d' ' -f 1`
md5_img=`cat md5_linux`
if [ "$md5_cur" != "$md5_img" ]; then
    echo "UPGRADE FAIL: Incorrect CRC";
    exit 1;
fi

killall igmpproxy udpxy

if [ -f /tmp/fw/utils/upgrade-bin ]; then
    FW_PATH="/tmp/fw"
else
    if [ -f /tmp/auto_fw_upgrade/utils/upgrade-bin ]; then
        FW_PATH="/tmp/auto_fw_upgrade"
    else
        if [ -f /tmp/dhcp_fw_upgrade/utils/upgrade-bin ]; then
            FW_PATH="/tmp/dhcp_fw_upgrade"
        else
            FW_PATH="/tmp/fw_tr069"
        fi
    fi
fi

chmod +x $FW_PATH/utils/upgrade-bin

cur_major=$(cat /version|cut -d'.' -f 1)
cur_minor=$(cat /version|cut -d'.' -f 2)

#Workaround for 1.5.0
if [ $cur_major -eq 1 ]; then
    if [ $cur_minor -eq 5 ]; then
	   mv /bin/factory /bin/_factory
    fi
fi

echo 3 > /proc/sys/vm/drop_caches
sleep 1

echo "Upgrade firmware started" > /dev/console

#Workaround for RT
#/bin/aipc_util -b

#$FW_PATH/utils/upgrade-bin ./linux.bin both &> /dev/console
$FW_PATH/utils/upgrade-bin ./linux.bin &> /dev/console
RETVAL=$?

if [ "$RETVAL" != "0" ]; then
    if [ "$RETVAL" = "254" ]; then
        echo "UPGRADE FAIL: upgrade process is already in progress" > /dev/console;
        echo "UPGRADE FAIL: upgrade process is already in progress";
        exit 2;
    fi
    echo "UPGRADE FAIL: Error at read/write operation" > /dev/console;
    echo "UPGRADE FAIL: Error at read/write operation";
    exit 1;
fi

if [ $cur_major -eq 1 ]; then
    if [ $cur_minor -eq 5 ]; then
	mv /bin/_factory /bin/factory
    fi
fi

if [ -e "$FW_PATH/defaults" ];then
    echo "UPGRADE : update def.yaml" > /dev/console;
    echo "UPGRADE : update def.yaml";
    cd $FW_PATH
    cat /proc/mtd | grep "mtd2" > /dev/null
    if [ $? == 0 ]; then
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml
    else
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml_old
    fi
    cd -
fi

md5sum set linux1 `cat $FW_PATH/md5_linux`
md5sum set linux2 `cat $FW_PATH/md5_linux`

echo "UPGRADE SUCCESSFULL" > /dev/console
exit 0;

==> WB-11P_1.2.0.329.tar.gz: upgrade.sh <==
#!/bin/sh

echo "Start firmware upgrading" > /dev/console

# some validation
if [ -f "./fmw_board_type" ]; then
    cur_board=`factory board | sed y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/ | sed s/-//g | grep -o ^[A-Z]*[0-9]*`
    case "$cur_board"  in
    "WB10")    board_type="WB1x";;
    "WB11")    board_type="WB1x";;
    esac

    if [ -z "$board_type" ]; then
        echo "UPGRADE FAIL: wrong factory settings" > /dev/console
        exit 1;
    fi

    fmw_type=`cat ./fmw_board_type`
    if [ "$fmw_type" != "$board_type" ]; then
        echo "UPGRADE FAIL: firmware for $fmw_type but board is $cur_board" > /dev/console
        exit 1;
    fi
fi

md5_cur=`busybox md5sum ./linux.bin | cut -d' ' -f 1`
md5_img=`cat md5_linux`
if [ "$md5_cur" != "$md5_img" ]; then
    echo "UPGRADE FAIL: Incorrect CRC";
    exit 1;
fi

#killall igmpproxy udpxy

if [ -f /tmp/fw/utils/upgrade-bin ]; then
    FW_PATH="/tmp/fw"
else
    if [ -f /tmp/auto_fw_upgrade/utils/upgrade-bin ]; then
        FW_PATH="/tmp/auto_fw_upgrade"
    else
        if [ -f /tmp/dhcp_fw_upgrade/utils/upgrade-bin ]; then
            FW_PATH="/tmp/dhcp_fw_upgrade"
        else
            FW_PATH="/tmp/fw_tr069"
        fi
    fi
fi

chmod +x $FW_PATH/utils/upgrade-bin

cur_major=$(cat /version|cut -d'.' -f 1)
cur_minor=$(cat /version|cut -d'.' -f 2)

#Workaround for 1.5.0
#if [ $cur_major -eq 1 ]; then
#    if [ $cur_minor -eq 5 ]; then
#	   mv /bin/factory /bin/_factory
#    fi
#fi

echo 3 > /proc/sys/vm/drop_caches
sleep 1

echo "Upgrade firmware started" > /dev/console

#Workaround for RT
#/bin/aipc_util -b

#$FW_PATH/utils/upgrade-bin ./linux.bin both &> /dev/console
$FW_PATH/utils/upgrade-bin ./linux.bin &> /dev/console
RETVAL=$?

if [ "$RETVAL" != "0" ]; then
    if [ "$RETVAL" = "254" ]; then
        echo "UPGRADE FAIL: upgrade process is already in progress" > /dev/console;
        echo "UPGRADE FAIL: upgrade process is already in progress";
        exit 2;
    fi
    echo "UPGRADE FAIL: Error at read/write operation" > /dev/console;
    echo "UPGRADE FAIL: Error at read/write operation";
    exit 1;
fi

#if [ $cur_major -eq 1 ]; then
#    if [ $cur_minor -eq 5 ]; then
#	mv /bin/_factory /bin/factory
#    fi
#fi

if [ -e "$FW_PATH/defaults" ];then
    echo "UPGRADE : update def.yaml" > /dev/console;
    echo "UPGRADE : update def.yaml";
    cd $FW_PATH
    cat /proc/mtd | grep "mtd2" > /dev/null
    if [ $? == 0 ]; then
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml
    else
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml_old
    fi
    cd -
fi

bversion="0"
if [ -f "/bin/boot_version" ];then
	res=`/bin/boot_version`
  	if [ "$res" != "" ];then
        bversion="1"
  	fi
fi

if [ "$bversion" == "1" ];then
    bank="`cat /proc/bootbank`"
    if [ "$bank" == "1" ];then
        /bin/md5sum set linux2 `cat $FW_PATH/md5_linux`
    else
        /bin/md5sum set linux1 `cat $FW_PATH/md5_linux`
    fi
else
        echo "Old loader"
fi


echo "UPGRADE SUCCESSFULL" > /dev/console
exit 0;
